pub struct MsgSubmitProposal {
pub messages: Vec<Any>,
pub initial_deposit: Vec<Coin>,
pub proposer: String,
pub metadata: String,
pub title: String,
pub summary: String,
}Expand description
MsgSubmitProposal defines an sdk.Msg type that supports submitting arbitrary proposal Content.
Fields
messages: Vec<Any>messages are the arbitrary messages to be executed if proposal passes.
initial_deposit: Vec<Coin>initial_deposit is the deposit value that must be paid at proposal submission.
proposer: Stringproposer is the account address of the proposer.
metadata: Stringmetadata is any arbitrary metadata attached to the proposal.
title: Stringtitle is the title of the proposal.
Since: cosmos-sdk 0.47
summary: Stringsummary is the summary of the proposal
Since: cosmos-sdk 0.47
Implementations